# -*- coding: utf-8 -*-
# Copyright © 2006 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

from gettext import gettext as _
msg0001 = _("Cannot perform operation in readonly mode")
msg0002 = _("Replacing spaces please wait...")
msg0003 = _("No spaces found to replace")
msg0004 = _("Replaced spaces with tabs")
msg0005 = _("Replacing tabs please wait...")
msg0006 = _("Replaced tabs with spaces")
msg0007 = _("No tabs found to replace")
msg0008 = _("Removing spaces please wait...")
msg0009 = _("No spaces were found at end of line")
msg0010 = _("Removed spaces at end of lines")
msg0011 = _("S_paces")
msg0012 = _("_Tabs to Spaces")
msg0013 = _("_Spaces to Tabs")
msg0014 = _("_Remove Trailing Spaces")
